# -*- coding: utf-8 -*-

from datetime import datetime

from tools import timer, trace
from View.Plot.APlot import APlot

from PyQt5.QtCore import (
    QCoreApplication
)

from View.BoundaryCondition.Edit.translate import *

_translate = QCoreApplication.translate

class Plot(APlot):
    def __init__(self, canvas=None, data=None, toolbar=None):
        super(Plot, self).__init__(
            canvas=canvas,
            data=data,
            toolbar=toolbar
        )

    def custom_ticks(self):
        t0 = datetime.fromtimestamp(0)
        nb = len(self.data.data)
        mod = int(nb / 5)

        fx = list(
            map(
                lambda x: x[1],
                filter(
                    lambda x: x[0] % mod == 0,
                    enumerate(self.data.data)
                )
            )
        )
        xx = list(map(lambda v: v[0], fx))
        xt = list(
            map(
                lambda v: str(
                    datetime.fromtimestamp(v[0]) - t0
                ).split(",")[0]\
                .replace("days", _translate("BoundaryCondition", "days"))\
                .replace("day", _translate("BoundaryCondition", "day")),
                fx
            )
        )

        self.canvas.axes.set_xticks(ticks=xx, labels=xt, rotation=45)


    @timer
    def draw(self):
        self.canvas.axes.cla()
        self.canvas.axes.grid(color='grey', linestyle='--', linewidth=0.5)

        if len(self.data) == 0:
            self._init = False
            return

        # Plot data
        x = list(map(lambda v: v[0], self.data.data))
        y = list(map(lambda v: v[1], self.data.data))
        self._line, = self.canvas.axes.plot(
            x, y,
            color='r', lw=1.,
            markersize=5, marker='+',
            picker=30,
        )

        self.custom_ticks()

        # Plot label
        header = self.data.header
        self.canvas.axes.set_xlabel(
            table_headers[header[0]], color='black', fontsize=10
        )
        self.canvas.axes.set_ylabel(
            table_headers[header[1]], color='black', fontsize=10
        )

        self.canvas.axes.autoscale_view(True, True, True)
        self.canvas.figure.tight_layout()
        self.canvas.figure.canvas.draw_idle()
        #self.toolbar.update()

        self._init = True

    @timer
    def update(self, ind=None):
        if self._init == False:
            self.draw()
            return

        x = list(map(lambda v: v[0], self.data.data))
        y = list(map(lambda v: v[1], self.data.data))

        self._line.set_data(x, y)

        self.custom_ticks()

        self.canvas.axes.relim()
        self.canvas.axes.autoscale()
        self.canvas.figure.tight_layout()
        self.canvas.figure.canvas.draw_idle()
